/*
*  Name:      exceptions.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   UESQLC exceptions
*  Date:      $Date: 1999/04/20 14:04:07 $
*  Revision:  $Revision: 1.6 $
*
*  Copyright (C) 1996-1998  Rafael Jesus Alcantara Perez <ralcan@vnet.es>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _EXCEPTIONS_UESQLC__
#define _EXCEPTIONS_UESQLC__

#include <mpcl/base_exception.hh>
#include <mpcl/warning_exception.hh>
#include <mpcl/error_exception.hh>
#include <mpcl/fatal_exception.hh>


/*
*  C O N S T A N T S
*/

extern const char*   pkcExceptionUESQLC_WarningDescription;
extern const char*   pkcExceptionUESQLC_ErrorDescription;
extern const char*   pkcExceptionUESQLC_FatalDescription;


/*
*  E X C E P T I O N S
*
*    TExceptionUESQLC:          Parent class of exceptions in UESQLC family.
*    TExceptionUESQLC_Warning:  Warning message.
*    TExceptionUESQLC_Error:    Error message.
*    TExceptionUESQLC_Fatal:    Compiler runtime error message.
*/

class TExceptionUESQLC: virtual public mpcl::TBaseException 
{

  protected:

    /*
    *  S E L E C T O R S
    */

    void putOnStream (ostream& rtTARGET_OSTREAM) const;

};  /* class TExceptionUESQLC */


class TExceptionUESQLC_Warning           :
  virtual public mpcl::TBaseException    ,
  public         TExceptionUESQLC        ,
  public         mpcl::TWarningException
{

  public:

    TExceptionUESQLC_Warning ( const char*   pkcSPECIFIC_DESCRIPTION = NULL ,
                               const char*   pkcFILE_NAME            = NULL ,
                               const int     kiLINE_NUMBER           = 0    ) :
      TBaseException    ( pkcExceptionUESQLC_WarningDescription ,
                          pkcSPECIFIC_DESCRIPTION               ,
                          pkcFILE_NAME                          ,
                          kiLINE_NUMBER                         )             ,
      TExceptionUESQLC  ()                                                    ,
      TWarningException ()                                                    {}
    /*
    *  Description:  Builds the instance with a generic and, if any,
    *                a specific description of the exception.
    */

};  /* class TExceptionUESQLC_Warning */


class TExceptionUESQLC_Error           :
  virtual public mpcl::TBaseException  ,
  public         TExceptionUESQLC      ,
  public         mpcl::TErrorException
{

  public:

    TExceptionUESQLC_Error ( const char*   pkcSPECIFIC_DESCRIPTION = NULL ,
                             const char*   pkcFILE_NAME            = NULL ,
                             const int     kiLINE_NUMBER           = 0    ) :
      TBaseException   ( pkcExceptionUESQLC_ErrorDescription ,
                         pkcSPECIFIC_DESCRIPTION             ,
                         pkcFILE_NAME                        ,
                         kiLINE_NUMBER                       )              ,
      TExceptionUESQLC ()                                                   ,
      TErrorException  ()                                                   {}
    
    /*
    *  Description:  Builds the instance with a generic and, if any,
    *                a specific description of the exception.
    */

};  /* class TExceptionUESQLC_Error */


class TExceptionUESQLC_Fatal           :
  virtual public mpcl::TBaseException  ,
  public         TExceptionUESQLC      ,
  public         mpcl::TFatalException
{

  public:

    TExceptionUESQLC_Fatal ( const char*   pkcSPECIFIC_DESCRIPTION = NULL ,
                             const char*   pkcFILE_NAME            = NULL ,
                             const int     kiLINE_NUMBER           = 0    ) :
      TBaseException   ( pkcExceptionUESQLC_FatalDescription ,
                         pkcSPECIFIC_DESCRIPTION             ,
                         pkcFILE_NAME                        ,
                         kiLINE_NUMBER                       )              ,
      TExceptionUESQLC ()                                                   ,
      TFatalException  ()                                                   {}
    
    /*
    *  Description:  Builds the instance with a generic and, if any,
    *                a specific description of the exception.
    */


  protected:

    /*
    *  S E L E C T O R S
    */

    void putOnStream (ostream& rtTARGET_OSTREAM) const;

};  /* class TExceptionUESQLC_Fatal */

#endif  /* not _EXCEPTIONS_UESQLC__ */
