#ifndef _INFORMIX_CPLUS_2_53_UC2__
#define _INFORMIX_CPLUS_2_53_UC2__
#include <stdlib.h>
#include <it.h>
#include <mpcl/test.h>
#include <mpcl/string.hh>
#include <mpcl/linked_map.hh>
#include <uesqlc/defs-uesqlc.hh>


/*
*  UESQLC::informix-cplus-2.53.UC2 internal definitions.
*/

#define IX_INSTANTIATE(pkcFORMAT, zINDEX, ppkcVARIABLES)  \
  Format (pkcFORMAT, ppkcVARIABLES [zINDEX + 1])

#define IX_NOT_FOUND_CONDITION ( ( PQresultStatus (htInformixManager.ptPgresult) == PGRES_EMPTY_QUERY ) || \
                                 ( !PQntuples (htInformixManager.ptPgresult) )                           )


/*
*  Execute command but don't display results (hidden).
*/
#define IXH_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_ITCONN)                              \
{                                                                                     \
  htInformixManager.ptAuxPgresult = PQexec (ptSOURCE_ITCONN, pkcSOURCE_INSTRUCTION);  \
  if ( htInformixManager.ptAuxPgresult )                                              \
  {                                                                                   \
    PQclear (htInformixManager.ptAuxPgresult);                                        \
  }                                                                                   \
}


/*
*  Execute command and display results (show).
*/
#define IXS_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_ITCONN, ERROR_ACTION)             \
{                                                                                  \
  IX_EXEC (pkcSOURCE_INSTRUCTION, ptSOURCE_ITCONN, ERROR_ACTION);                  \
  if ( htInformixManager.ptPgresult ) { PQclear (htInformixManager.ptPgresult); }  \
}


#define IX_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_ITCONN, ERROR_ACTION)  \
{  \
  if ( !htInformixManager.initiate() ) \
  { \
    ERROR_ACTION \
  } \
  TEST_WRITE_INFO ("%s", pkcSOURCE_INSTRUCTION); \
  htInformixManager.ptPgresult = PQexec (ptSOURCE_ITCONN, pkcSOURCE_INSTRUCTION); \
  if ( !htInformixManager.ptPgresult ) \
  { \
    /* \
    *  Condition:           transaction rollback \
    *  Class subcondition:  statement completion unknown \
    */ \
    SQLCODE = -1; SQLSTATE = "40003"; \
    cerr << PQerrorMessage (htInformixManager.ptItconnection); \
    ERROR_ACTION \
  } \
  else \
  { \
    if ( ( PQresultStatus (htInformixManager.ptPgresult) == PGRES_COMMAND_OK ) || ( PQresultStatus (htInformixManager.ptPgresult) == PGRES_TUPLES_OK ) ) \
    { \
      SQLCODE = 0; SQLSTATE = "00000"; \
    } \
    else \
    { \
      /* \
      *  Condition:           transaction rollback \
      *  Class subcondition:  statement completion unknown \
      */ \
      SQLCODE = -1; SQLSTATE = "40003"; \
      cerr << PQerrorMessage (htInformixManager.ptItconnection); \
      ERROR_ACTION \
    } \
  } \
}


/*
*  UESQLC::informix-cplus-2.53.UC2 internal classes.
*/

class TInformixManager
{

  public:

    static ITConnection*   ptItconnection;
    static PGresult*       ptPgresult;
    static PGresult*       ptAuxPgresult;
    static string          stSqlInstruction;
    static char*           pcHost;
    static char*           pcDatabaseName;

  
  private:

    TLinkedMap<string, ITConnection*>   tConnectionMap;
    string                                 stCurrentConnection;
    bool                                   gIsThereConnection;

  
  public:

    /*
    *  C O N S T R U C T O R S
    */

    TInformixManager (void)       :
      tConnectionMap      ()      ,
      stCurrentConnection ()      ,
      gIsThereConnection  (false) {}

    ~TInformixManager (void);

    bool initiate (void);

    void connect (const string& rkyCONNECTION_NAME, const ITConnection* pktCONNECTION);

    void disconnect (const string& rkyCONNECTION_NAME);

    void disconnectCurrent (void);

    ITConnection* setCurrentConnection (const string& rkyCONNECTION_NAME);


  public:

    /*
    *  S E L E C T O R S
    */

    bool existsDefaultConnection (void) const;

    bool isConnected (const string& rkyCONNECTION_NAME) const;

    ITConnection* currentConnection (void) const;

    ITConnection* connection (const string& rkyCONNECTION_NAME) const;

    void finish (void);

};  /* class TInformixManager */


#endif  /* not _INFORMIX_CPLUS_2_53_UC2__ */
