#include "oracle-oci-7.x.hh"


/*
*  UESQLC::oracle-oci-7.x internal variables initiation.
*/

TOci7xManager   htOci7xManager;


/*
*  Name:      test-base-1.uesql.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for UESQL
*  Date:      $Date: 1999/04/20 14:04:18 $
*  Revision:  $Revision: 1.1 $
*
*  Copyright (C) 1996-1998  Rafael Jesus Alcantara Perez <ralcan@vnet.es>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdlib>
#include <iostream>
#include <mpcl/test.h>
#include <mpcl/string.hh>
#include <mpcl/config_processor.hh>

using namespace mpcl;


string GetErrorMessage (void)
{

  string   yMessage;

  if ( SQLSTATE == "00000" )
  {
    yMessage = "successful completion";
  }
  else if ( SQLSTATE == "02000" )
  {
    yMessage = "no data";
  }
  else if ( SQLSTATE == "08001" )
  {
    yMessage = "connection exception: SQL-client unable to establish SQL-connection";
  }
  else if ( SQLSTATE == "08002" )
  {
    yMessage = "connection exception: connection name in use";
  }
  else if ( SQLSTATE == "08003" )
  {
    yMessage = "connection exception: connection does not exist";
  }
  else if ( SQLSTATE == "08007" )
  {
    yMessage = "connection exception: transaction resolution unknown";
  }
  else if ( SQLSTATE == "21000" )
  {
    yMessage = "cardinality violation";
  }
  else if ( SQLSTATE == "34000" )
  {
    yMessage = "invalid cursor name";
  }
  else if ( SQLSTATE == "40003" )
  {
    yMessage = "transaction rollback: statement completion unknown";
  }
  else if ( SQLSTATE == "42000" )
  {
    yMessage = "syntax error or access rule violation";
  }
  else
  {
    yMessage = "unknown error";
  }
  return yMessage;

}  /* GetErrorMessage() */


/*
*  Parameters and arguments:
*
*    {--hostname, -o}=HOSTNAME
*    {--username, -u}=USERNAME
*    {--password, -p}=PASSWORD
*/
int main (int argc, const char* argv[])
{

  TConfigProcessor   tConfig;
  size_t             zRecordCount = 0;

  TEST_INIT ("test-base-1");
  TEST_START_WATCH;

  string   yVar0;
  string   yVar1;
  string   yVar2;
  string   yAttribName;
  string   yCursorName;
  string   yUserName;
  string   yHostName;
  string   yCodeValue = "'002'";

  /*
  *  Define string constants names for options.
  */ 
  tConfig.addOption ("hostname", "o", "localhost");
  tConfig.addOption ("username", "u", getenv ("USER"));
  tConfig.addOption ("password", "p", "");
  tConfig.setCommandLineParameters (argc, argv);
  tConfig.processOptions();
  
  yHostName = Format ("'%s'", tConfig ["hostname"].value().c_str());
  if ( tConfig ["password"].value().empty() )
  {
    yUserName = Format ("'%s'", tConfig ["username"].value().c_str());
  }
  else
  {
    yUserName = Format ( "'%s/%s'"                            ,
                         tConfig ["username"].value().c_str() ,
                         tConfig ["password"].value().c_str() );
  }

  TEST_WRITE_INFO ("HOSTNAME = %s", yHostName.c_str());
  TEST_WRITE_INFO ("USER     = %s", yUserName.c_str());
  if ( !yHostName.empty() && !yUserName.empty() )
  {
{
/*
*  OCI 7.x instructions.
*/
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
{
mpcl::xstring   hstSqlServerName;
mpcl::xstring   hstConnectionName;
mpcl::xstring   hstUserName;
mpcl::xstring   hstUserId;

htOci7xManager.initiateEmbeddedVariableMap (NULL , yHostName.c_str(), yUserName.c_str(), NULL);
hstSqlServerName  = htOci7xManager.instantiateString ("%s");
hstConnectionName = htOci7xManager.kyDefaultConnectionName;
hstUserName       = htOci7xManager.instantiateString ("%s");
hstUserId         = Format ("%s@%s", hstUserName.c_str(), hstSqlServerName.c_str());
hstConnectionName.suppress ('\'');
hstUserId.suppress ('\'');
htOci7xManager.iCode = htOci7xManager.connect (hstConnectionName, (text*) hstUserId.c_str());
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("", yHostName.c_str(), yUserName.c_str());
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("CREATE TABLE JOBS (CODE CHARACTER (3) NOT NULL, WORKER_COUNT INTEGER)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("CREATE TABLE WORKERS (WORK_CODE CHARACTER (3) NOT NULL, NAME CHARACTER (40) NOT NULL, HOURS DECIMAL (5))");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("ALTER TABLE WORKERS ADD STATE CHARACTER (40)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("ALTER TABLE WORKERS ADD PHONE_NUMBER INTEGER");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DELETE FROM JOBS WHERE ( CODE = %s )", yCodeValue.c_str());
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DELETE FROM JOBS WHERE ( CODE = '001' )");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DELETE FROM WORKERS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO JOBS VALUES ('001', 100)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO JOBS VALUES ('002', 250)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS VALUES ('001', 'myname', 40, 'Andalucia', 5550000)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS VALUES ('001', 'yourname', 35, 'Extremadura', 5550001)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS VALUES ('001', 'hisname', 25, 'Catalunya', 5550002)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS VALUES ('002', 'john', 35, 'New England', 5550003)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS VALUES ('002', 'james', 35, 'Washington', 5550004)");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS WHERE ( NAME = 'myname' )");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("INSERT INTO WORKERS SELECT WORK_CODE, NAME, HOURS, STATE, PHONE_NUMBER FROM WORKERS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto cardinality_check;);
}
{
Cda_Def*   hpsCurrentCda_def;
int        J = 1;

htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
htOci7xManager.stSqlInstruction = htOci7xManager.instantiateString ("SELECT HOURS FROM WORKERS, JOBS WHERE ( WORK_CODE = CODE )");
OCI7X_EXEC_CURSOR (htOci7xManager.stSqlInstruction, "OCI7XCN_AUX");
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto cardinality_check;);
hpsCurrentCda_def = htOci7xManager.cursor ("OCI7XCN_AUX");
if ( !hpsCurrentCda_def )
{
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto cardinality_check;);
}
else
{
OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar1);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, htOci7xManager.closeCursor ("OCI7XCN_AUX"); goto cardinality_check;);
++J;
  htOci7xManager.iCode = ofetch (hpsCurrentCda_def);
  OCI7X_CHECK_SINGLENESS (hpsCurrentCda_def, htOci7xManager.closeCursor ("OCI7XCN_AUX"); goto cardinality_check;);
  htOci7xManager.closeCursor ("OCI7XCN_AUX"); 
}
}if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("SELECT HOURS INTO  FROM WORKERS, JOBS WHERE ( WORK_CODE = CODE )");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto cardinality_check;);
}
}
    TEST_FAIL;


  cardinality_check:

    TEST_STRINGS (SQLSTATE.c_str(), "21000");
    yAttribName = "WORK_CODE";
    yCursorName = "MYCURSOR";
{
/*
*  OCI 7.x instructions.
*/
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
{
Cda_Def*   hpsCurrentCda_def;
int        J = 1;

htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
htOci7xManager.stSqlInstruction = htOci7xManager.instantiateString ("SELECT COUNT (*) FROM WORKERS WHERE ( NAME = 'myname' )");
OCI7X_EXEC_CURSOR (htOci7xManager.stSqlInstruction, "OCI7XCN_AUX");
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
hpsCurrentCda_def = htOci7xManager.cursor ("OCI7XCN_AUX");
if ( !hpsCurrentCda_def )
{
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
else
{
OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar2);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, htOci7xManager.closeCursor ("OCI7XCN_AUX"); goto error;);
++J;
  htOci7xManager.iCode = ofetch (hpsCurrentCda_def);
  OCI7X_CHECK_SINGLENESS (hpsCurrentCda_def, htOci7xManager.closeCursor ("OCI7XCN_AUX"); goto error;);
  htOci7xManager.closeCursor ("OCI7XCN_AUX"); 
}
}if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("SELECT COUNT (*) INTO  FROM WORKERS WHERE ( NAME = 'myname' )");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("UPDATE WORKERS SET PHONE_NUMBER = WORKERS.PHONE_NUMBER WHERE ( ( WORKERS.NAME = 'myname' ) AND ( WORKERS.NAME = NAME ) )");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("REVOKE ALL PRIVILEGES ON JOBS FROM PUBLIC CASCADE CONSTRAINTS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("REVOKE ALL PRIVILEGES ON WORKERS FROM PUBLIC ");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("GRANT SELECT ON JOBS TO PUBLIC");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("CREATE VIEW VIEW1 AS SELECT * FROM JOBS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DROP VIEW VIEW1");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
{
string   hstCursorName;

htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
hstCursorName                   = htOci7xManager.instantiateString ("MYCURSOR");
htOci7xManager.stSqlInstruction = htOci7xManager.instantiateString ("SELECT CODE FROM JOBS WHERE ( CODE = '001' )");
OCI7X_DECLARE_CURSOR (htOci7xManager.stSqlInstruction, hstCursorName.c_str());
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("{
  string   hstCursorName;

  htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
  hstCursorName = htOci7xManager.instantiateString ("MYCURSOR");
  OCI7X_OPEN_CURSOR (hstCursorName.c_str());
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
{
string    hstDynamicCursorName;
Cda_Def*   hpsCurrentCda_def;
int        J = 1;

hstDynamicCursorName = Format ("%s", yCursorName.c_str());
hpsCurrentCda_def = htOci7xManager.cursor (hstDynamicCursorName.c_str());
if ( !hpsCurrentCda_def )
{
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
else
{
  OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar0);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
++J;
  htOci7xManager.iCode = ofetch (hpsCurrentCda_def);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
  OCI7X_CHECK_EMPTYNESS (hpsCurrentCda_def, goto not_found;);
}
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("", yCursorName.c_str());
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
{
htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);

htOci7xManager.iCode = htOci7xManager.closeCursor (htOci7xManager.instantiateString ("MYCURSOR"));
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DROP TABLE JOBS CASCADE CONSTRAINTS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
}

    TEST_STRINGS (SQLSTATE.c_str(), "00000");
    TEST_STRINGS (yVar2.c_str(),   "4");
    TEST_STRINGS (yVar0.c_str(),   "001");

{
/*
*  OCI 7.x instructions.
*/
{
string   hstCursorName;

htOci7xManager.initiateEmbeddedVariableMap (NULL , yAttribName.c_str(), NULL);
hstCursorName                   = htOci7xManager.instantiateString ("MYCURSOR");
htOci7xManager.stSqlInstruction = htOci7xManager.instantiateString ("SELECT %s, NAME, HOURS FROM WORKERS");
OCI7X_DECLARE_CURSOR (htOci7xManager.stSqlInstruction, hstCursorName.c_str());
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("", yAttribName.c_str());
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("{
  string   hstCursorName;

  htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
  hstCursorName = htOci7xManager.instantiateString ("MYCURSOR");
  OCI7X_OPEN_CURSOR (hstCursorName.c_str());
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
}
    
    if ( _ptTargetFile )
    {
      fprintf (_ptTargetFile, "%s\n", "WORK_CODE NAME                                     HOURS");
      fprintf (_ptTargetFile, "%s\n", "========= ======================================== =====");
    }
    for (;;)
    {
{
/*
*  OCI 7.x instructions.
*/
{
Cda_Def*   hpsCurrentCda_def;
int        J = 1;

htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);
hpsCurrentCda_def = htOci7xManager.cursor (htOci7xManager.instantiateString ("MYCURSOR"));
if ( !hpsCurrentCda_def )
{
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
else
{
  OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar0);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
++J;
OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar1);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
++J;
OCI7X_DEFINE_INPUT (hpsCurrentCda_def, J, yVar2);
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
++J;
  htOci7xManager.iCode = ofetch (hpsCurrentCda_def);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
  OCI7X_CHECK_EMPTYNESS (hpsCurrentCda_def, goto loop_end;);
}
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
}
      if ( _ptTargetFile )
      {
        fprintf (_ptTargetFile, "%9s %40s %5s\n", yVar0.c_str(), yVar1.c_str(), yVar2.c_str());
      }
      ++zRecordCount;
    }


  loop_end:

{
/*
*  OCI 7.x instructions.
*/
{
htOci7xManager.initiateEmbeddedVariableMap (NULL , NULL);

htOci7xManager.iCode = htOci7xManager.closeCursor (htOci7xManager.instantiateString ("MYCURSOR"));
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
htOci7xManager.iCode = htOci7xManager.disconnectCurrent();
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
}

{
/*
*  OCI 7.x instructions.
*/
{
mpcl::xstring   hstSqlServerName;
mpcl::xstring   hstConnectionName;
mpcl::xstring   hstUserName;
mpcl::xstring   hstUserId;

htOci7xManager.initiateEmbeddedVariableMap (NULL , yHostName.c_str(), yUserName.c_str(), NULL);
hstSqlServerName  = htOci7xManager.instantiateString ("%s");
hstConnectionName = htOci7xManager.instantiateString ("_'myconnection'");
hstUserName       = htOci7xManager.instantiateString ("%s");
hstUserId         = Format ("%s@%s", hstUserName.c_str(), hstSqlServerName.c_str());
hstConnectionName.suppress ('\'');
hstUserId.suppress ('\'');
htOci7xManager.iCode = htOci7xManager.connect (hstConnectionName, (text*) hstUserId.c_str());
OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( false )
{
  htOci7xManager.stSqlInstruction = Format ("", yHostName.c_str(), yUserName.c_str());
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
if ( true )
{
  htOci7xManager.stSqlInstruction = Format ("DROP TABLE WORKERS CASCADE CONSTRAINTS");
  OCI7X_EXEC (htOci7xManager.stSqlInstruction);
  OCI7X_UPDATE_STATUS (htOci7xManager.iCode, goto error;);
}
}
    goto end;

    
  error:

    cerr << "SQLSTATE="    << SQLSTATE << endl;
    cerr << "SQLCODE="     << SQLCODE  << endl;
    cerr << "DESCRIPTION=" << GetErrorMessage() << endl;
    TEST_FAIL_WITH_CODE (SQLCODE);  
    goto end;

    
  not_found:

    cerr << "Search failed\n";
    TEST_FAIL_WITH_CODE (2);
    goto end;
  }

end:
  
  TEST_STOP_WATCH;
  TEST_DISPLAY_WATCH;
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  /* main() */

