#ifndef _POSTGRESQL_LIBPQ_6_2_X__
#define _POSTGRESQL_LIBPQ_6_2_X__
#include <stdlib.h>
#include <libpq-fe.h>
#include <mpcl/test.h>
#include <mpcl/string.hh>
#include <mpcl/linked_map.hh>
#include <uesqlc/defs-uesqlc.hh>


/*
*  UESQLC::postgresql-libpq-6.2.x internal definitions.
*/

#define PG62X_INSTANTIATE(pkcFORMAT, zINDEX, ppkcVARIABLES)  \
  Format (pkcFORMAT, ppkcVARIABLES [zINDEX + 1])

#define PG62X_NOT_FOUND_CONDITION ( ( PQresultStatus (htPostgresql62xManager.ptPgresult) == PGRES_EMPTY_QUERY ) || \
                                    ( !PQntuples (htPostgresql62xManager.ptPgresult) )                           )


/*
*  Execute command but don't display it.
*/
#define PGIV_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_PGCONN)                                  \
{                                                                                          \
  htPostgresql62xManager.ptAuxPgresult = PQexec (ptSOURCE_PGCONN, pkcSOURCE_INSTRUCTION);  \
  if ( htPostgresql62xManager.ptAuxPgresult )                                              \
  {                                                                                        \
    PQclear (htPostgresql62xManager.ptAuxPgresult);                                        \
  }                                                                                        \
}


/*
*  Execute command and display it.
*/
#define PGV_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_PGCONN, ERROR_ACTION)                       \
{                                                                                            \
  PG_EXEC (pkcSOURCE_INSTRUCTION, ptSOURCE_PGCONN, ERROR_ACTION);                            \
  if ( htPostgresql62xManager.ptPgresult ) { PQclear (htPostgresql62xManager.ptPgresult); }  \
}


#define PG_EXEC(pkcSOURCE_INSTRUCTION, ptSOURCE_PGCONN, ERROR_ACTION)  \
{  \
  if ( !htPostgresql62xManager.initiate() ) \
  { \
    ERROR_ACTION \
  } \
  TEST_WRITE_INFO ("%s", pkcSOURCE_INSTRUCTION); \
  htPostgresql62xManager.ptPgresult = PQexec (ptSOURCE_PGCONN, pkcSOURCE_INSTRUCTION); \
  if ( !htPostgresql62xManager.ptPgresult ) \
  { \
    /* \
    *  Condition:           transaction rollback \
    *  Class subcondition:  statement completion unknown \
    */ \
    SQLCODE = -1; SQLSTATE = "40003"; \
    cerr << PQerrorMessage (htPostgresql62xManager.ptPgconn); \
    ERROR_ACTION \
  } \
  else \
  { \
    if ( ( PQresultStatus (htPostgresql62xManager.ptPgresult) == PGRES_COMMAND_OK ) || ( PQresultStatus (htPostgresql62xManager.ptPgresult) == PGRES_TUPLES_OK ) ) \
    { \
      SQLCODE = 0; SQLSTATE = "00000"; \
    } \
    else \
    { \
      /* \
      *  Condition:           transaction rollback \
      *  Class subcondition:  statement completion unknown \
      */ \
      SQLCODE = -1; SQLSTATE = "40003"; \
      cerr << PQerrorMessage (htPostgresql62xManager.ptPgconn); \
      ERROR_ACTION \
    } \
  } \
}


/*
*  UESQLC::postgresql-libpq-6.2.x internal classes.
*/

class TPostgresql62xManager
{

  public:

    static PGconn*     ptPgconn;
    static PGresult*   ptPgresult;
    static PGresult*   ptAuxPgresult;
    static string      stSqlInstruction;
    static char*       pcHost;
    static char*       pcDatabaseName;

  
  private:

    TLinkedMap<string, PGconn*>   tConnectionMap;
    string                           stCurrentConnection;
    bool                             gIsThereConnection;

  
  public:

    /*
    *  C O N S T R U C T O R S
    */

    TPostgresql62xManager (void)  :
      tConnectionMap      ()      ,
      stCurrentConnection ()      ,
      gIsThereConnection  (false) {}

    ~TPostgresql62xManager (void);

    bool initiate (void);

    void connect (const string& rkyCONNECTION_NAME, const PGconn* pktCONNECTION);

    void disconnect (const string& rkyCONNECTION_NAME);

    void disconnectCurrent (void);

    PGconn* setCurrentConnection (const string& rkyCONNECTION_NAME);


  public:

    /*
    *  S E L E C T O R S
    */

    bool existsDefaultConnection (void) const;

    bool isConnected (const string& rkyCONNECTION_NAME) const;

    PGconn* currentConnection (void) const;

    PGconn* connection (const string& rkyCONNECTION_NAME) const;

    void finish (void);

};  /* class TPostgresql62xManager */


#endif  /* not _POSTGRESQL_LIBPQ_6_2_X__ */
